@@ -3,33 +3,43 @@ package Module::ScanDeps::Static;
 use strict;
 use warnings;
 
-our $VERSION = '0.9';
+require Module::ScanDeps::VERSION;
 
 use 5.010;
 
 use Carp;
 use Data::Dumper;
-use English qw{ -no_match_vars };
+use English qw( -no_match_vars );
 use ExtUtils::MM;
 use Getopt::Long;
-use JSON::PP;
+use JSON;
 use Module::CoreList;
 use Pod::Usage;
-use Pod::Find qw{ pod_where };
+use Pod::Find qw( pod_where );
 use Readonly;
 use IO::Scalar;
-use List::Util qw{ max };
+use List::Util qw( max none );
 use version;
 
-use parent qw{ Class::Accessor::Fast };
+use parent qw( Class::Accessor::Fast );
+
+our @OPTIONS = qw(
+  add_version
+  core
+  handle
+  include_require
+  json
+  min_core_version
+  path
+  perlreq
+  raw
+  require
+  separator
+  text
+);
 
 __PACKAGE__->follow_best_practice;
-__PACKAGE__->mk_accessors(
-  qw{
-    json raw text handle include_require core
-    add_version perlreq require path separator min_core_version
-  }
-);
+__PACKAGE__->mk_accessors(@OPTIONS);
 
 # booleans
 Readonly my $TRUE  => 1;
@@ -47,7 +57,7 @@ Readonly my $NEWLINE      => qq{\n};
 Readonly my $SLASH        => q{/};
 Readonly my $SPACE        => q{ };
 
-Readonly my $DEFAULT_MIN_CORE_VERSION => '5.8.9';
+Readonly my $DEFAULT_MIN_CORE_VERSION => $PERL_VERSION;
 
 our $HAVE_VERSION = eval {
   require version;
@@ -76,10 +86,16 @@ sub new {
   }
 
   # defaults
-  $options{'core'}             //= $TRUE;
-  $options{'include_require'}  //= $FALSE;
-  $options{'add_version'}      //= $TRUE;
-  $options{'min_core_version'} //= $DEFAULT_MIN_CORE_VERSION;
+  $options{core}             //= $TRUE;
+  $options{include_require}  //= $FALSE;
+  $options{add_version}      //= $TRUE;
+  $options{min_core_version} //= $DEFAULT_MIN_CORE_VERSION;
+
+  # check for unknown options
+  foreach my $o ( keys %options ) {
+    die "unknown option $o\n"
+      if none { $_ eq $o } @OPTIONS;
+  }
 
   my $self = $class->SUPER::new( \%options );
 
@@ -128,8 +144,11 @@ sub get_module_version {
 
     $module_version{'path'} = $path;
 
-    $module_version{'version'}
-      = eval { return ExtUtils::MM->parse_version($path) // 0; };
+    $module_version{'version'} = eval {
+      my $v = ExtUtils::MM->parse_version($path);
+
+      return $v eq 'undef' ? 0 : $v || 0;
+    };
 
     last;
   }
@@ -137,6 +156,17 @@ sub get_module_version {
   return \%module_version;
 }
 
+########################################################################
+sub min_core_version {
+########################################################################
+  my ($self) = @_;
+
+  my $min_core_version = $self->get_min_core_version;
+  $min_core_version = $min_core_version =~ /^v/xsm ? $min_core_version : "v$min_core_version";
+
+  return version->parse($min_core_version)->numify;
+}
+
 ########################################################################
 sub is_core {
 ########################################################################
@@ -151,23 +181,23 @@ sub is_core {
   if (@ms) {
     my $first_release = Module::CoreList->first_release($module);
 
-    my $first_release_version = version->parse($first_release);
-    my $min_core_version      = $self->get_min_core_version;
+    my $removed_version = Module::CoreList->removed_from($module);
+
+    my $min_core_version = $self->min_core_version();
 
     # consider a module core if its first release was less than some
     # version of Perl. This is done because CPAN testers don't seem to
     # test modules against Perls that are older than 5.8.9 - however,
-    # some modules like JSON::PP did not appear until > 5.10
-
-    # print {*STDERR} "$first_release_version $min_core_version";
-
-    $core = version->parse($first_release_version)
-      <= version->parse($min_core_version) ? 1 : 0;
+    # some modules like JSON::PP did not appear until after 5.10
 
+    if ($removed_version) {
+      $core = $removed_version > $min_core_version;
+    }
+    elsif ($first_release) {
+      $core = $first_release <= $min_core_version;
+    }
   }
 
-  # print {*STDERR} "$module: [$core]\n";
-
   return $core;
 }
 
@@ -284,7 +314,7 @@ sub parse_line {  ## no critic (Subroutines::ProhibitExcessComplexity)
   #   eval "require Term::Rendezvous;" or die $@;
   #   eval { require Carp } if defined $^S; # If error/warning during compilation,
 
-  ## no critic (RegularExpressions::ProhibitComplexRegexes, RegularExpressions::RequireBracesForMultiline)
+  ## no critic (ProhibitComplexRegexes, RequireBracesForMultiline)
   if (
     ( $line =~ /\A(\s*) # we hope the inclusion starts the line
          (require|use)\s+(?![{])      # do not want 'do {' loops
@@ -302,7 +332,7 @@ sub parse_line {  ## no critic (Subroutines::ProhibitExcessComplexity)
 
     $version //= $EMPTY;
 
-    # print {*STDERR} "$whitespace, $statement, $module, $version\n";
+    #print {*STDERR} "$whitespace, $statement, $module, $version\n";
 
     # fix misidentification of version when use parent qw{ Foo };
     #
@@ -320,6 +350,9 @@ sub parse_line {  ## no critic (Subroutines::ProhibitExcessComplexity)
         $version = $EMPTY;
       }
     }
+
+    #print {*STDERR} "$whitespace, $statement, $module, $version\n";
+
     #
 
     # we only consider require statements that are flushed against
@@ -366,17 +399,17 @@ sub parse_line {  ## no critic (Subroutines::ProhibitExcessComplexity)
     $module =~ s/qw.*\z//xsm;
     $module =~ s/[(].*\z//xsm;
 
-    # if the module ends with .pm, strip it to leave only basename.
-    $module =~ s/[.]pm\z//xsm;
-
     # some perl programmers write 'require URI/URL;' when
     # they mean 'require URI::URL;'
+    if ( $module !~ /[.]pl$/xsm ) {
+      # if the module ends with .pm, strip it to leave only basename.
+      $module =~ s/[.]pm\z//xsm;
 
-    $module =~ s/\//::/xsm;
+      $module =~ s/\//::/xsgm;
+    }
 
     # trim off trailing parentheses if any.  Sometimes people pass
     # the module an empty list.
-
     $module =~ s/[(]\s*[)]$//xsm;
 
     if ( $module =~ /\Av?([\d._]+)\z/xsm ) {
@@ -409,6 +442,8 @@ sub parse_line {  ## no critic (Subroutines::ProhibitExcessComplexity)
     if ( $statement eq 'use'
       && ( $module eq 'base' || $module eq 'parent' ) ) {
       $self->add_require( $module, $version );
+      #print {*STDERR}
+      #  "statement: $statement module: $module, version: $version\n";
 
       if ( $version =~ /\Aqw\s*[{(\/'"]\s*([^)}\/"']+?)\s*[})\/"']/xsm ) {
         foreach ( split $SPACE, $1 ) {
@@ -425,8 +460,19 @@ sub parse_line {  ## no critic (Subroutines::ProhibitExcessComplexity)
     if ( $version && $version !~ /\A$modver_re\z/oxsm ) {
       $version = undef;
     }
+    #print {*STDERR}
+    #  "statement: $statement module: $module, version: $version\n";
 
-    $self->add_require( $module, $version );
+    my @module_list = split /\s+/xsm, $module;
+
+    if ( @module_list > 1 ) {
+      for (@module_list) {
+        $self->add_require( $_, $EMPTY );
+      }
+    }
+    else {
+      $self->add_require( $module, $version );
+    }
   }
 
   return $line;
@@ -513,6 +559,8 @@ sub add_require {
 ########################################################################
   my ( $self, $module, $newver ) = @_;
 
+  $newver //= $EMPTY;
+
   $module =~ s/\A\s*//xsm;
   $module =~ s/\s*\z//xsm;
 
@@ -535,7 +583,7 @@ sub add_require {
     $require->{$module} = $m->{'version'} // $EMPTY;
   }
   else {
-    $require->{$module} = $newver;
+    $require->{$module} = $newver // $EMPTY;
   }
 
   return $self;
@@ -575,7 +623,7 @@ sub format_json {
       };
   }
 
-  my $json = JSON::PP->new->pretty;
+  my $json = JSON->new->pretty;
 
   return wantarray ? @requirements : $json->encode( \@requirements );
 }
@@ -585,10 +633,12 @@ sub get_dependencies {
 ########################################################################
   my ( $self, %options ) = @_;
 
-  if ( $self->get_json ) {
+  my $format = $options{format} // $EMPTY;
+
+  if ( ( $options{format} && $options{format} eq 'json' ) || $self->get_json ) {
     return scalar $self->format_json;
   }
-  elsif ( $self->get_text || $self->get_raw ) {
+  elsif ( ( $options{format} && $options{format} eq 'text' ) || $self->get_text || $self->get_raw ) {
     return $self->format_text;
   }
   else {
@@ -622,6 +672,7 @@ sub format_text {
     }
     else {
       $name = "'$name'";
+      $separator //= $SPACE;
     }
 
     push @output, sprintf $format, $name, $separator, $version // $EMPTY;
@@ -684,16 +735,20 @@ sub main {
     'min-core-version' => '5.8.9',
   );
 
-  GetOptions(
-    \%options,              'json|j',
-    'text|t',               'core!',
-    'min-core-version|m=s', 'add-version|a!',
-    'include-require|i!',   'help|h',
-    'separator|s=s',        'version|v',
-    'raw|r',
+  my @option_specs = qw(
+    add-version|a!
+    core!
+    help|h
+    include-require|i!
+    json|j
+    min-core-version|m=s
+    raw|r
+    separator|s=s
+    text|t
+    version|v
   );
 
-  # print {*STDERR} Dumper( \%options );
+  GetOptions( \%options, @option_specs );
 
   if ( $options{'version'} ) {
     pod2usage(
@@ -706,10 +761,9 @@ sub main {
 
   if ( $options{'help'} ) {
     pod2usage(
-      -exitval  => 1,
-      -input    => pod_where( { -inc => 1 }, __PACKAGE__ ),
-      -sections => 'USAGE|VERSION',
-      -verbose  => 99,
+      -exitval => 1,
+      -input   => pod_where( { -inc => 1 }, __PACKAGE__ ),
+      -verbose => 1,
     );
   }
 
@@ -740,13 +794,17 @@ Module::ScanDeps::Static - a cleanup of rpmbuild's perl.req
 
 =head1 SYNOPSIS
 
- my $scanner = Module::ScanDeps::Static->new({ file => 'myfile.pl' });
+ scandeps-static.pl [options] Module
+
+If "Module" is not provided, the script will read from STDIN.
+
+ my $scanner = Module::ScanDeps::Static->new({ path => 'myfile.pl' });
  $scanner->parse;
  print $scanner->format_text;
 
 =head1 DESCRIPTION
 
-This module is a mashup (and cleanup) of the `/usr/lib/rpm/perl.req`
+This module is a mashup (and cleanup) of the F</usr/lib/rpm/perl.req>
 file found in the rpm build tools library (see L</LICENSE>) below.
 
 Successful identification of the required Perl modules for a module or
@@ -762,18 +820,25 @@ Perl script or module.  It's not perfect and the regular expressions
 could use some polishing, but it works on a broad enough set of
 situations as to be useful.
 
-I<NOTE: Only direct dependencies are returned by this module. If you
-want a recursive search for dependencies, use C<scandeps.pl>>
+I<Only direct dependencies are returned by this module. If you
+want a recursive search for dependencies, use C<find-requires.pl>
+included in this distribution.>
 
-I<!!EXPERIMENTAL!!>
+=head1 OPTIONS
 
-I<The methods and output of this module are subject to revision!>
-
-=head1 USAGE
-
- scandeps-static.pl [options] Module
-
-If "Module" is not provided, the script will read from STDIN.
+ --add-version, -a        add version numbers to output
+ --no-add-version         don't add version numbers to output
+ --core                   include core modules (default)
+ --no-core                don't include core modules
+ --help, -h               help
+ --include-require, -i    include 'require'd modules
+ --no-include-require     don't include required modules
+ --json, -j               output JSON formatted list
+ --min-core-version, -m   minimum version of perl to consider core
+ --raw, -r                raw output
+ --separator, -s          separator for output (default: =>)
+ --text, -t               output as text (default)
+ --version, -v            verion
 
 =head2 Examples
 
@@ -781,7 +846,10 @@ If "Module" is not provided, the script will read from STDIN.
 
  scandeps-static.pl --json $(which scandeps-static.pl)
 
-=head2 Options
+I<Use the C<find-requires> script included in this distribution to
+recurse directories and create dependency files like C<cpanfile>>.
+
+=head1 OPTION DETAILS
 
 =over 5
 
@@ -827,7 +895,7 @@ identify the dependencies for your script B<AND> you know you will be
 using a specific version of Perl, then set the C<min-core-version> to
 that version of Perl.
 
-default: 5.8.9
+default: $PERL_VERSION
 
 =item --separator, -s
 
@@ -847,6 +915,7 @@ default: B<--text>
 Output the list with no quotes separated by a single whitespace
 character.
 
+
 =back
 
 =head1 WHAT IS A DEPENDENCY?
@@ -873,7 +942,7 @@ Use the C<--include-require> to expand the definition of a dependency
 to any module or Perl script that is the argument of the C<require>
 statement.
 
-=item * Allow detection of the C<parent>, C<base> statemens use of curly braces.
+=item * Allow detection of the C<parent>, C<base> statements use of curly braces.
 
 The regular expression and algorithm in C<parse> has been enhanced to
 detect the use of curly braces in C<use> or C<parent> declarations.
@@ -882,7 +951,8 @@ detect the use of curly braces in C<use> or C<parent> declarations.
 
 Use the C<--no-core> option to ignore core modules.
 
-=item * Add the current version of installed module if version not explicitly specified.
+=item * Add the current version of an installed module if the version
+is not explicitly specified.
 
 =back
 
@@ -934,7 +1004,7 @@ default: B<false>
 =item min_core_version
 
 The minimum version of Perl which will be used to decide if a module
-is include in Perl core.
+is included in Perl core.
 
 default: 5.8.9
 
@@ -967,7 +1037,8 @@ After calling the C<parse()> method, call this method to retrieve a
 hash containing the dependencies and (potentially) their version
 numbers.
 
- $scanner->parse
+ $scanner->parse;
+ my $requires = $scanner->get_require;
 
 =head2 parse
 
@@ -991,7 +1062,7 @@ numbers.
 
 =back
 
-Scans the specified input and returns a list Perl modulde dependencies.
+Scans the specified input and returns a list of Perl module dependencies.
 
 Use the C<get_dependencies> method to retrieve the dependencies as a
 formatted string or as a list of dependency objects. Use the
@@ -1021,7 +1092,7 @@ As JSON:
 
  print $scanner->get_dependencies( format => 'text' )
 
- Module::Name >= version
+ Module::Name => version
  ...
 
 In scalar context in the absence of an argument returns a JSON
@@ -1030,23 +1101,23 @@ contain the keys "name" and "version" for each dependency.
 
 =head1 VERSION
 
-0.9
+1.007
 
 =head1 AUTHOR
 
-This module is largely a lift and drop of Ken Este's `perl.req` script
+This module is largely a lift and drop of Ken Este's C<perl.req> script
 lifted from rpm build tools.
 
 Ken Estes Mail.com kestes@staff.mail.com
 
-The method `parse` is a cleaned up version of `process_file` from the
+The method C<parse> is a cleaned up version of C<process_file> from the
 same script.
 
 Rob Lauer - <bigfoot@cpan.org>
 
 =head1 LICENSE
 
-This statement was lifted right from C<perl.req>...
+This statement was lifted directly from C<perl.req>...
 
 =over 10
 
